#!/usr/bin/env bash

function assemble_index {
    # $1 src
    # $2 webroot
    # $3 directory below src
    # $4 template directory

    sed -e 's/^        //' <<< "
        import json
        properties = json.loads('''$(cat "$1/$3/properties.json")''')
        index_path = ''
        print('''
            echo 'Assembling index:'
            type=$(ls "$1/$3/" | grep "content\\..*body" | sed -e 's/^content\.//;s/body$//')
            echo \"  - Type:   \$type\"
            echo '  - Title:      ''' + properties['page title'] + ''''
            echo '  - Slogan:     ''' + properties['section slogan'] + ''''
            echo '  - Custom CSS: ''' + properties['inject css'] + ''''
            sed -e 's/%TITLE%/''' + properties['page title'] + '''/;s/%SLOGAN%/''' +properties['section slogan']+ '''/;s/%ADDITIONAL_STYLE%/''' +properties['inject css']+ '''/' < $4/html_begin.template > $2/$3/index.\$type
            cat $1/$3/content.\${type}body >> $2/$3/index.\$type
            cat $4/html_end.template >> $2/$3/index.\$type
        ''')
    " | python3 | bash
}

function copy_additional_files {
    # $1 src
    # $2 webroot
    # $3 directory below src

    sed -e 's/^        //' <<< "
        import json
        properties = json.loads('''$(cat "$1/$3/properties.json")''')
        for additional_file in properties['additional files']:
            print('cp --no-dereference -v \"$1/$3/' + additional_file + '\" \"$2/$3/' + additional_file + '\"')
    " | python3 | bash
}

function build {
    # $1 src
    # $2 webroot
    # $3 template directory

    original_ifs="$IFS"
    IFS=$'\n'
    for dir in $(cd "$1" && find . -type d)
    do
        echo ">> $dir"
        [ ! -d "$2/dir" ] && mkdir "$2/$dir"
        assemble_index "$1" "$2" "$dir" "$3"
        copy_additional_files "$1" "$2" "$dir"
    done
    IFS="$original_ifs"
}

echo ">>> Cleaning webroots:"
./reset.sh

echo ">>> Building external:"
build src webroot templates
